@@ -9,6 +9,7 @@ import subprocess
 import linuxcnc
 from .status import Status
 from .command import Command
+from .hal import Hal
 from .error import Error
 
 class CNC:
@@ -17,13 +18,14 @@ class CNC:
         self.framework = framework
         self.status = Status(self)
         self.command = Command(self)
+        self.hal = Hal(self)
         self.error = Error(self)
 
     def start(self):
         linuxcnc_pid = subprocess.Popen(["pidof", "-x", "linuxcnc"], stdout=subprocess.PIPE)
         linuxcnc_pid_result = linuxcnc_pid.communicate()[0]
         if len(linuxcnc_pid_result) == 0:
-            self.framework.utils.service.service_write({"command": "launch:restart", "message": "", "data": False})
+            # self.framework.utils.service.service_write({"command": "launch:restart", "message": "", "data": False})
             sys.exit()
         self.framework.machine.is_alive = True
         self.framework.utils.service.service_write({"command": "launch:restart", "message": "", "data": True})
@@ -121,3 +123,7 @@ class CNC:
             if message["command"] == "desktop:program:open":
                 if message["data"] != "":
                     self.command.program_open(message["data"])
+
+            if message["command"] == "service:package:status":
+                self.framework.package.set_status(message["data"]["package"], message["data"]["status"])
+
